@@ -27,8 +27,8 @@ from pytz.tzinfo import DstTzInfo, StaticTzInfo  # noqa
 
 # I test for expected version to ensure the correct version of pytz is
 # actually being tested.
-EXPECTED_VERSION = '2022.1'
-EXPECTED_OLSON_VERSION = '2022a'
+EXPECTED_VERSION = '2022.2'
+EXPECTED_OLSON_VERSION = '2022b'
 
 fmt = '%Y-%m-%d %H:%M:%S %Z%z'
 
@@ -758,10 +758,9 @@ class CommonTimezonesTestCase(unittest.TestCase):
         self.assertTrue('US/Eastern' in pytz.common_timezones_set)
 
     def test_belfast(self):
-        # Belfast uses London time.
         self.assertTrue('Europe/Belfast' in pytz.all_timezones_set)
-        self.assertFalse('Europe/Belfast' in pytz.common_timezones)
-        self.assertFalse('Europe/Belfast' in pytz.common_timezones_set)
+        self.assertTrue('Europe/Belfast' in pytz.common_timezones)
+        self.assertTrue('Europe/Belfast' in pytz.common_timezones_set)
 
 
 class ZoneCaseInsensitivityTestCase(unittest.TestCase):
